pitchtools.calculate_melodic_chromatic_interval_class_from_pitch_carrier_to_pitch_carrier
=========================================================================================

.. autofunction:: abjad.tools.pitchtools.calculate_melodic_chromatic_interval_class_from_pitch_carrier_to_pitch_carrier
